@@ -1073,7 +1073,7 @@ void documentation_browser::handle_index_clicked (const QUrl& url,
                                                   const QString&)
 {
   if (url.scheme () == "qthelp")
-    setSource (url);
+    setSource (QUrl (url));
   else
     QDesktopServices::openUrl (url);
 }
